slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPSetWorkVecs

Sets a number of work vectors into a NEP object

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPSetWorkVecs(NEP nep,PetscInt nw)

Collective on nep

### Input Parameters

| nep | - nonlinear eigensolver context
| nw | - number of work vectors to allocate

### Developer Notes

This is SLEPC_EXTERN because it may be required by user plugin NEP implementations.

### See Also

NEPSetUp()

### Level

developer

### Location

src/nep/interface/nepdefault.c
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages